@@ -17,7 +17,7 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #  MA 02110-1301, USA.
 #
-#  version: 20220814134232
+#  version: 20220815112045
 
 import re
 import mariadb
@@ -174,7 +174,7 @@ class MeasurementDatabase:
 
         return rows
 
-    def retrieveLastMeasurement(self, stationid):
+    def retrieveLastMeasurement(self, stationid, _names=None, _unique_stations=None):
         """
         Return the last measurement data for a station or all stations.
 
@@ -184,14 +184,21 @@ class MeasurementDatabase:
         Returns:
             list: a list of dict objects, one for each station
         """
-        names = {nm[0]: nm[1] for nm in self.names("*")}
+        print(stationid, _names, _unique_stations)
+        if _names is None:
+            _names = {nm[0]: nm[1] for nm in self.names("*")}
+
+        if _unique_stations is None:
+            _unique_stations = self.uniqueStations()
 
         if stationid == "*":
             rows = []
-            cursor = self.connection.cursor()
-            cursor.execute("SELECT DISTINCT(Stationid) FROM Measurements")
-            for row in cursor.fetchall():
-                rows.extend(self.retrieveLastMeasurement(row[0]))
+            for unique_station in _unique_stations:
+                rows.extend(
+                    self.retrieveLastMeasurement(
+                        unique_station, _names=_names, _unique_stations=_unique_stations
+                    )
+                )
         else:
             # get the data
             cursor = self.connection.cursor()
@@ -205,10 +212,10 @@ class MeasurementDatabase:
             # mariadb / mysql timestamps are in UTC but returned as 'naive' datetime objects
             rows = [
                 {
-                    "time": row[0].replace(tzinfo=tz.UTC).astimezone(tz.tzlocal()),
+                    "time": row[0].replace(tzinfo=tz.UTC),
                     "deltat": datetime.now() - row[0],
                     "stationid": row[1],
-                    "name": names.get(row[1], "unknown"),
+                    "name": _names.get(row[1], "unknown"),
                     "temperature": row[2],
                     "humidity": row[3],
                 }
@@ -231,7 +238,7 @@ class MeasurementDatabase:
             f"""
             <div class="measurement{' late' if m['deltat'].total_seconds()>24*3600 else ''}" id="{m["stationid"]}">
             <div class="station">{m["name"]}</div>
-            <div class="time" data-time="{m["time"]}">{m['time']:%H:%M}</div>
+            <div class="time" data-time="{m["time"]}"></div>
             <div class="temp">{m["temperature"]:.1f}<span class="degrees">°C</span></div>
             <div class="hum">{m["humidity"]:.0f}<span class=percent>%</span></div>
             </div>"""
@@ -247,7 +254,7 @@ class MeasurementDatabase:
         .hum {float:left; font-size:12pt;}
         .late { background-color:red; }
         """
-        return f"""<html>
+        html = f"""<html>
         <head><meta charset="UTF-8"><meta http-equiv="refresh" content="300"><title>Temperatuur binnen</title>
         <style>{style}</style>
         </head>
@@ -256,8 +263,11 @@ class MeasurementDatabase:
         {mdivs}
         </div>
         </body>
+        <script>document.querySelectorAll("[data-time]").forEach(function(e){{d=new Date(e.getAttribute("data-time"));e.innerHTML=d.getHours() + ":" + d.getMinutes().toString().padStart(2, '0')}})</script>
         </html>
         """
+        print(html)
+        return html
 
     def retrieveMeasurementsLast24Hours(self, stationid):
         ltz = tz.tzlocal()
@@ -266,6 +276,12 @@ class MeasurementDatabase:
         start = end - d
         return self.retrieveMeasurements(stationid, start, end)
 
+    def uniqueStations(self):
+        conn = self.connection
+        cursor = conn.cursor()
+        cursor.execute("SELECT DISTINCT(Stationid) FROM Measurements")
+        return [row[0] for row in cursor.fetchall()]
+
     def names(self, stationid, name=None):
         """
         Insert or replace a name for a stationid, or return a list of all stations._
