@@ -219,6 +219,34 @@ class TestInterceptor:
                         print(captured.out)
                         assert ihinstance.wfile.getvalue()[:15] == b"HTTP/1.0 200 OK"
 
+    def test_GET_JSON(self, database, capsys):
+        stationid = "jsonid-123456"
+        interceptorhandler = InterceptorHandlerFactory.getHandler(database)
+
+        database.names(
+            stationid, "json room1"
+        )  # without a stationid mapping we never get anything back
+        start = datetime.now()
+        database.storeMeasurement(Measurement(stationid, 10, 40))
+        with mock.patch.object(interceptorhandler, "finish", finish):
+            with mock.patch.object(
+                interceptorhandler, "date_time_string", date_time_string
+            ):
+                with mock.patch.object(
+                    interceptorhandler, "version_string", version_string
+                ):
+                    with mock.patch.object(interceptorhandler, "wbufsize", lambda: 1):
+                        start = datetime.now()
+                        request = MockRequest(
+                            b"/json?id=%s" % bytes(stationid, "UTF-8")
+                        )
+                        ihinstance = interceptorhandler(
+                            request, ("127.0.0.1", 12345), "testserver.example.org"
+                        )
+                        captured = capsys.readouterr()
+                        print(captured.out)
+                        assert ihinstance.wfile.getvalue()[:15] == b"HTTP/1.0 200 OK"
+
     def test_GET_NAME(self, database, capsys):
         stationid = "newname-123456"
         name = "NewName"
